@@ -13,7 +13,7 @@ import torch
 import wandb
 
 from .movielens.data import csv_imdb_ratings_to_dataframe
-from .utils import Timer
+from .utils import Timer, profile
 
 if TYPE_CHECKING:
     from .interface import RecommenderModuleBase
@@ -85,9 +85,11 @@ class MovieMarkdownGenerator:
             return markdown, ""
 
         movie_results = request.json()["movie_results"][0]
-        poster_url = self.poster_url_from_tmdb_poster_path(
-            poster_path=movie_results["poster_path"]
-        )
+        poster_path = movie_results["poster_path"]
+        if poster_path is not None:
+            poster_url = self.poster_url_from_tmdb_poster_path(poster_path=poster_path)
+        else:
+            poster_url = ""
         title = movie_results["title"]
         imdb_url = self.imdb_url(imdb_id=imdb_id)
         markdown = f"""[{title}]({imdb_url})"""
@@ -113,6 +115,7 @@ class Session:
         self.movie_id, self.initial_markdown, self.initial_poster_url = self.content()
         self.content_task = self.content()
 
+    @profile()
     def content(self):
         explicit = self.recommender.to_torch_coo(
             scipy.sparse.coo_matrix(np.nan_to_num(self.explicit).reshape(1, -1))
@@ -169,6 +172,7 @@ class Session:
         self.content_task = asyncio.create_task(self.async_content())
         return markdown, poster_url
 
+    @profile()
     def upload(self, file_object: TextIO) -> str:
         """Function for file block upload method."""
         filename = file_object.name
